@@ -127,7 +127,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -143,14 +143,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_kms
-import aws_cdk.aws_lambda
-import aws_cdk.aws_sns
-import constructs
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class SnsToLambda(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambda",
 ):
@@ -160,16 +160,16 @@ class SnsToLambda(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -187,20 +187,7 @@ class SnsToLambda(
         :summary: Constructs a new instance of the LambdaToSns class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__be7576e9f341f837f8d5b94654fe4f7efae321bf43ddfe27f7ec6ddebb2629ff)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SnsToLambdaProps(
@@ -217,13 +204,13 @@ class SnsToLambda(
 
     @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
-    def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
+    def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "lambdaFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="snsTopic")
-    def sns_topic(self) -> aws_cdk.aws_sns.Topic:
-        return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "snsTopic"))
+    def sns_topic(self) -> _aws_cdk_aws_sns_ceddda9d.Topic:
+        return typing.cast(_aws_cdk_aws_sns_ceddda9d.Topic, jsii.get(self, "snsTopic"))
 
 
 @jsii.data_type(
@@ -244,12 +231,12 @@ class SnsToLambdaProps:
         self,
         *,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps. Default: - False if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
@@ -263,24 +250,13 @@ class SnsToLambdaProps:
         :summary: The properties for the SnsToLambda class.
         '''
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+            encryption_key_props = _aws_cdk_aws_kms_ceddda9d.KeyProps(**encryption_key_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
-            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
+            topic_props = _aws_cdk_aws_sns_ceddda9d.TopicProps(**topic_props)
         if __debug__:
-            def stub(
-                *,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4a8c67defb6976ca9dd77b9f7ab7111f52b7e7e0e3565adaac5e8e9d8d5d4b48)
             check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
             check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
             check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
@@ -288,7 +264,7 @@ class SnsToLambdaProps:
             check_type(argname="argument existing_topic_obj", value=existing_topic_obj, expected_type=type_hints["existing_topic_obj"])
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
             check_type(argname="argument topic_props", value=topic_props, expected_type=type_hints["topic_props"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if enable_encryption_with_customer_managed_key is not None:
             self._values["enable_encryption_with_customer_managed_key"] = enable_encryption_with_customer_managed_key
         if encryption_key is not None:
@@ -318,60 +294,64 @@ class SnsToLambdaProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key]:
         '''An optional, imported encryption key to encrypt the SNS Topic with.
 
         :default: - None
         '''
         result = self._values.get("encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key], result)
 
     @builtins.property
-    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+    def encryption_key_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps]:
         '''Optional user provided properties to override the default properties for the KMS encryption key used to  encrypt the SNS Topic with.
 
         :default: - None
         '''
         result = self._values.get("encryption_key_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps], result)
 
     @builtins.property
-    def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    def existing_lambda_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
-    def existing_topic_obj(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
+    def existing_topic_obj(self) -> typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic]:
         '''Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
 
         :default: - Default props are used
         '''
         result = self._values.get("existing_topic_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.Topic], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic], result)
 
     @builtins.property
     def lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''User provided props to override the default props for the Lambda function.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
-    def topic_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
+    def topic_props(self) -> typing.Optional[_aws_cdk_aws_sns_ceddda9d.TopicProps]:
         '''Optional user provided properties to override the default properties for the SNS topic.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("topic_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.TopicProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_ceddda9d.TopicProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -391,3 +371,31 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__be7576e9f341f837f8d5b94654fe4f7efae321bf43ddfe27f7ec6ddebb2629ff(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4a8c67defb6976ca9dd77b9f7ab7111f52b7e7e0e3565adaac5e8e9d8d5d4b48(
+    *,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
